@@ -32,7 +32,7 @@ class Cache {
 		for(int i=0;i<l;i++) head[i] = new head_t();
 		size /= 4;
 		size -= l * (16/4);	// sizeof(head_t) == 16
-		size = Math.max(size, (long) 2*l);  // cache must be large enough for two columns
+		size = Math.max(size, 2* (long) l);  // cache must be large enough for two columns
 		lru_head = new head_t();
 		lru_head.next = lru_head.prev = lru_head;
 	}
@@ -163,12 +163,6 @@ abstract class Kernel extends QMatrix {
 	        return ret;
 	}
 
-	private static double tanh(double x)
-	{
-		double e = Math.exp(x);
-		return 1.0-2.0/(e*e+1);
-	}
-
 	double kernel_function(int i, int j)
 	{
 		switch(kernel_type)
@@ -180,7 +174,7 @@ abstract class Kernel extends QMatrix {
 			case svm_parameter.RBF:
 				return Math.exp(-gamma*(x_square[i]+x_square[j]-2*dot(x[i],x[j])));
 			case svm_parameter.SIGMOID:
-				return tanh(gamma*dot(x[i],x[j])+coef0);
+				return Math.tanh(gamma*dot(x[i],x[j])+coef0);
 			case svm_parameter.PRECOMPUTED:
 				return x[i][(int)(x[j][0].value)].value;
 			default:
@@ -278,7 +272,7 @@ abstract class Kernel extends QMatrix {
 				return Math.exp(-param.gamma*sum);
 			}
 			case svm_parameter.SIGMOID:
-				return tanh(param.gamma*dot(x,y)+param.coef0);
+				return Math.tanh(param.gamma*dot(x,y)+param.coef0);
 			case svm_parameter.PRECOMPUTED:
 				return 	x[(int)(y[0].value)].value;
 			default:
@@ -1552,7 +1546,7 @@ public class svm {
 	
 		int max_iter=100; 	// Maximal number of iterations
 		double min_step=1e-10;	// Minimal step taken in line search
-		double sigma=1e-3;	// For numerically strict PD of Hessian
+		double sigma=1e-12;	// For numerically strict PD of Hessian
 		double eps=1e-5;
 		double hiTarget=(prior1+1.0)/(prior1+2.0);
 		double loTarget=1/(prior0+2.0);
